



FrChannels data/test.gwf
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrCheck -i data/test.gwf
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrCopy -i data/test.gwf -o copy.gwf
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrDiff -i1 data/test.gwf -i2 copy.gwf -t D1 -d 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrDump -i data/test.gwf -t D1
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrCopy -i data/test.gwf -o copy2.gwf -f 0 -l 1 -r 10
IF %ERRORLEVEL% NEQ 0 exit /B 1
FrTrend -s 1 -p trend- -d 5 -c D1 -f 925484670 -l 925484680 copy2.gwf
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
